# allthethings

Various utilities augmenting the python standard library.

- `allthethings.daterange.DateRange` – Date Ranges like `2020-01..2020-03-14`
- `allthethings.dates.at_end_of_month` – 28th? 30th? 31st?
- `allthethings.ranges.range_incl` and `allthethings.ranges.range_excl` – unopinoinated ranges that work with all sorts of types
- `allthethings.iterables.groupby` – like Scala's groupby, unlike Haskell's/Python's groupby
